package com.ekingwin.bas.cloud.solr.service.impl;

import com.ekingwin.bas.cloud.infra.service.BaseService;
import com.ekingwin.bas.cloud.solr.JiucaiyunSolrException;
import com.ekingwin.bas.cloud.solr.dao.IJiucaiyunSolrDao;
import com.ekingwin.bas.cloud.solr.dao.entity.JiucaiyunSolr;
import com.ekingwin.bas.cloud.solr.dao.entity.JiucaiyunSupplier;
import com.ekingwin.bas.cloud.solr.dto.*;
import com.ekingwin.bas.cloud.solr.service.IJiucaiyunSolrService;
import org.apache.commons.lang3.StringUtils;
import org.apache.solr.client.solrj.SolrClient;
import org.apache.solr.client.solrj.SolrQuery;
import org.apache.solr.client.solrj.SolrQuery.ORDER;
import org.apache.solr.client.solrj.response.FacetField;
import org.apache.solr.client.solrj.response.FacetField.Count;
import org.apache.solr.client.solrj.response.QueryResponse;
import org.apache.solr.common.SolrDocument;
import org.apache.solr.common.SolrDocumentList;
import org.apache.solr.common.SolrInputDocument;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Service
@Primary
public class JiucaiyunSolrServiceImpl extends BaseService implements IJiucaiyunSolrService {
	@Autowired
	private SolrClient solrClient;
	@Autowired
	private IJiucaiyunSolrDao jiucaiyunSolrDao;

	@Value("${preImage}")
	private String preImage;// #图片读取路径 门户图片直接读取物理地址

	// public static final Logger logger =
	// Logger.getLogger(JiucaiyunSolrServiceImpl.class);

	@Override
	public Boolean initData() throws JiucaiyunSolrException {
		try {
			List<JiucaiyunSolr> allData = jiucaiyunSolrDao.getAllData();
			for (JiucaiyunSolr data : allData) {
				SolrInputDocument doc = new SolrInputDocument();
				doc.setField("id", data.getId());
				doc.setField("jiucaiyun_ftnpjc", data.getFtnpjc());
				doc.setField("jiucaiyun_ftnpconfiguration", data.getFtnpconfiguration());
				doc.setField("jiucaiyun_name", data.getName());
				doc.setField("jiucaiyun_num", data.getGoodsnum());
				doc.setField("jiucaiyun_supplier_name", data.getSupplier());
				doc.setField("jiucaiyun_suppliernum", data.getSuppliernum());
				doc.setField("jiucaiyun_supplierid", data.getSupplierid());
				doc.setField("jiucaiyun_wareid", data.getWareid());
				doc.setField("jiucaiyun_description", data.getDescription());
				doc.setField("jiucaiyun_catalog", data.getCatalog());
				doc.setField("jiucaiyun_freightprice", data.getFreightprice());
				doc.setField("jiucaiyun_catalog_name", data.getCatalog() + "," + data.getCatalogname());
				doc.setField("jiucaiyun_price", data.getPrice());
				doc.setField("jiucaiyun_minimum_quantity", data.getMinimumquantity());
				String successdate = data.getSuccessdate();
				if (null == successdate || "".equals(successdate.trim())) {
					successdate = "长期有效";
				}
				doc.setField("jiucaiyun_successdate", successdate);
				doc.setField("jiucaiyun_salesvolume", data.getSalesVolume());
				doc.setField("jiucaiyun_brand", data.getBrand());
				doc.setField("jiucaiyun_brand_solr", data.getBrand());
				doc.setField("jiucaiyun_model", data.getModel());
				String url = data.getPricture();
				if ("京东".equals(data.getSupplier())) {
					doc.setField("jiucaiyun_type", "京东");
				} else if ("苏宁".equals(data.getSupplier())) {
					doc.setField("jiucaiyun_type", "苏宁");
				} else {
					doc.setField("jiucaiyun_type", "九彩云");
					url = preImage + url;
				}
				doc.setField("jiucaiyun_picture", url);
				doc.setField("jiucaiyun_pictureid", data.getImgid());
				String[] permissions = null;
				if (null != data.getSalesarea() && !"".equals(data.getSalesarea().trim())) {
					permissions = data.getSalesarea().split(",");
					doc.setField("jiucaiyun_permission", permissions);
				} else {
					permissions = new String[] { "" };
				}
				doc.setField("jiucaiyun_permission", permissions);
				
				String[] licensorids = null;
				if (null != data.getLicensorid() && !"".equals(data.getLicensorid().trim())) {
					licensorids = data.getLicensorid().split(",");
				} else {
					licensorids = new String[] { "" };
				}
				doc.setField("jiucaiyun_licensorid", licensorids);
				
				String[] licensornames = null;
				if (null != data.getLicensorname() && !"".equals(data.getLicensorname().trim())) {
					licensornames = data.getLicensorname().split(",");
				} else {
					licensornames = new String[] { "" };
				}
				doc.setField("jiucaiyun_licensor_name", licensornames);
				doc.setField("jiucaiyun_pricetype", data.getPricetype());
				
				solrClient.add(doc);
				solrClient.commit();
			}
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
		return true;
	}

	@Override
	public JiucaiyunSolrResponseDTO queryData(JiucaiyunSolrRequestDTO request) throws JiucaiyunSolrException {
		try {

			// int index = 5/0;
			// 索引条件
			SolrQuery params = new SolrQuery();
			params.setQuery(request.getJiucaiyun_keywords());
			String keyWord = "*";
			if (request.getJiucaiyun_keywords() != null && !"".equals(request.getJiucaiyun_keywords().trim())) {
				keyWord = request.getJiucaiyun_keywords().trim();
				/*params.addFacetQuery("jiucaiyun_keywords:" +"*"+keyWord+"*");*/
				//如果查询小于1时，从分词匹配
				if(keyWord.length()<=1){
					keyWord="*"+keyWord+"*";
				}
			}
			params.set("q", "jiucaiyun_keywords:" +keyWord);
			/*if (null != request.getJiucaiyun_catalog() && !"".equals(request.getJiucaiyun_catalog().trim())) {
				params.add("fq", "jiucaiyun_catalog:" + request.getJiucaiyun_catalog().trim());
			}*/
			if (null != request.getJiucaiyun_catalog() && !"".equals(request.getJiucaiyun_catalog().trim())) {
				String[] strs = request.getJiucaiyun_catalog().split(",");
				if (strs !=null && strs.length>1){
					String per = "";
					for (int i = 0; i < strs.length; i++) {
						if (i == 0) {
							per = per + " jiucaiyun_catalog:" + strs[i];
						} else {
							per = per + " OR jiucaiyun_catalog:" + strs[i];
						}
					}
					params.add("fq", per);
				}else{
					params.add("fq", "jiucaiyun_catalog:" + request.getJiucaiyun_catalog().trim());
				}

			}
			String brand2 = request.getJiucaiyun_brand();
			if (null != brand2 && !"".equals(brand2.trim())) {
				if (brand2.contains(" ")) {
					brand2 = brand2.trim().replace(" ", "\\ ");
				}
				// brand2 = SolrUtils.transformSolrMetacharactor(brand2);
				params.add("fq", "jiucaiyun_brand:" + brand2);
			}
			if (null != request.getJiucaiyun_price()) {
				String[] price = request.getJiucaiyun_price().split("-");
				if (price.length == 2) {
					params.add("fq", "jiucaiyun_price:[" + price[0] + " TO " + price[1] + "]");
				} else {
					params.add("fq", "jiucaiyun_price:[" + price[0] + " TO *]");
				}
			}
			String model2 = request.getJiucaiyun_model();
			if (null != model2 && !"".equals(model2.trim())) {
				if (model2.contains(" ")) {
					model2 = model2.trim().replace(" ", "\\ ");
				}
				// brand2 = SolrUtils.transformSolrMetacharactor(brand2);
				params.add("fq", "jiucaiyun_model:" + model2);
			}
			String jiucaiyun_ftnpjc = request.getJiucaiyun_ftnpjc();
			if (StringUtils.isNotBlank(jiucaiyun_ftnpjc)){
				if("XM".equals(jiucaiyun_ftnpjc)){
						String str="XZ";
						String perNmae="jiucaiyun_ftnpjc:" + jiucaiyun_ftnpjc.trim()+" or  jiucaiyun_ftnpjc:"+str.trim();
						params.add("fq", perNmae);
				}else {
					params.add("fq", "jiucaiyun_ftnpjc:" + jiucaiyun_ftnpjc.trim());
				}

			}
			String jiucaiyun_ftnpconfiguration = request.getJiucaiyun_ftnpconfiguration();
			if (StringUtils.isNotBlank(jiucaiyun_ftnpconfiguration)){
				params.add("fq", "jiucaiyun_ftnpconfiguration:" + jiucaiyun_ftnpconfiguration.trim());
			}

			if (null != request.getJiucaiyun_type() && !"".equals(request.getJiucaiyun_type().trim())) {
				params.add("fq", "jiucaiyun_type:" + request.getJiucaiyun_type().trim());
			}
			if (null != request.getJiucaiyun_supplierid() && !"".equals(request.getJiucaiyun_supplierid().trim())) {
				String[] strs = request.getJiucaiyun_supplierid().split(",");
				if (strs.length > 1) {
					String per = "";
					for (int i = 0; i < strs.length; i++) {
						if (i == 0) {
							per = per + " jiucaiyun_supplierid:" + strs[i];
						} else {
							per = per + " OR jiucaiyun_supplierid:" + strs[i];
						}
					}
					params.add("fq", per);
				} else {
//					params.add("fq", "jiucaiyun_supplierid:" + request.getJiucaiyun_supplierid().trim());
					String licensor = "jiucaiyun_supplierid:"+request.getJiucaiyun_supplierid().trim() + " OR jiucaiyun_licensorid:"+request.getJiucaiyun_supplierid().trim();
					params.add("fq", licensor);
					
				}
			}
			if (null != request.getJiucaiyun_suppliernum() && !"".equals(request.getJiucaiyun_suppliernum().trim())) {
				params.add("fq", "jiucaiyun_suppliernum:" + request.getJiucaiyun_suppliernum().trim());
			}
			if (null != request.getJiucaiyun_permission() && !"".equals(request.getJiucaiyun_permission().trim())) {
				String[] pers = request.getJiucaiyun_permission().trim().split(",");
				String per = "jiucaiyun_permission:\"\"";
				for (String str : pers) {
					per = per + " OR jiucaiyun_permission:" + str;
				}
				params.add("fq", per);
			}
			// 1:打开高亮的开关
			if (null != request.getJiucaiyun_keywords() && !"".equals(request.getJiucaiyun_keywords().trim())) {
				params.setHighlight(true);
				// 2:设置需要高亮的域
				params.addHighlightField("jiucaiyun_supplier_name");
				params.addHighlightField("jiucaiyun_name");
				// 3:高亮的前缀 后缀
				params.setHighlightSimplePre("<span style='color:red'>");
				params.setHighlightSimplePost("</span>");
			}
			// 分页
			params.setStart(request.getStartRow());
			params.setRows(request.getPageSize());
			// 排序
			if ("asc".equals(request.getJiucaiyun_price_order()) ) {
				params.setSort("jiucaiyun_price", ORDER.asc);
			} else if ("desc".equals(request.getJiucaiyun_price_order())) {
				params.setSort("jiucaiyun_price", ORDER.desc);
			}

			if ("asc".equals(request.getJiucaiyun_salesvolume_order())) {
				params.setSort("jiucaiyun_salesvolume", ORDER.asc);
			} else if ("desc".equals(request.getJiucaiyun_salesvolume_order())) {
				params.setSort("jiucaiyun_salesvolume", ORDER.desc);
			}
			params.set("wt", "json");
			params.set("facet", true);
			params.add("facet.field", "jiucaiyun_catalog_name");
			params.add("facet.field", "jiucaiyun_brand");
			params.add("facet.field", "jiucaiyun_model");
			params.add("facet.field", "jiucaiyun_type");
			QueryResponse query = solrClient.query(params);

			List<FacetField> facetFields = query.getFacetFields();
			List<JiucaiyunSolrCategoryDTO> category = new ArrayList<JiucaiyunSolrCategoryDTO>();
			List<JiucaiyunSolrBrandDTO> brands = new ArrayList<JiucaiyunSolrBrandDTO>();
			List<JiucaiyunSolrTypeDTO> type = new ArrayList<JiucaiyunSolrTypeDTO>();
			List<JiucaiyunSolrModelDTO> models = new ArrayList<JiucaiyunSolrModelDTO>();

			for (FacetField ff : facetFields) {
				String name = ff.getName();
				switch (name) {
				case "jiucaiyun_catalog_name":
					List<Count> cate = ff.getValues();
					for (Count c : cate) {
						if (c.getCount() > 0) {
							String[] strs = c.getName().split(",");
							category.add(new JiucaiyunSolrCategoryDTO(strs[0], strs[1]));
						}
					}

					break;
				case "jiucaiyun_brand":
					List<Count> brand = ff.getValues();
					for (Count c : brand) {
						if (c.getCount() > 0) {
							brands.add(new JiucaiyunSolrBrandDTO(c.getName()));
						}
					}
					break;
				case "jiucaiyun_type":
					List<Count> t = ff.getValues();
					for (Count c : t) {
						if (c.getCount() > 0) {
							type.add(new JiucaiyunSolrTypeDTO(c.getName()));
						}
					}
					break;
				case "jiucaiyun_model":
					List<Count> model = ff.getValues();
					for (Count c : model) {
						if (c.getCount() > 0) {
							models.add(new JiucaiyunSolrModelDTO(c.getName()));
						}
					}
					break;

				default:
					break;
				}
			}
			SolrDocumentList results = query.getResults();
			// 获取高亮
			Map<String, Map<String, List<String>>> highlighting = query.getHighlighting();
			// 1: Map K id V : map
			// 2: Map K name_ik V list
			// 3: list apache 不一个 多值 本次只有一个值 list.get(0)
			// 总条数
			long numFound = results.getNumFound();
			List<JiucaiyunSolrProductDTO> goodsList = new ArrayList<JiucaiyunSolrProductDTO>();

			for (SolrDocument doc : results) {
				JiucaiyunSolrProductDTO product = new JiucaiyunSolrProductDTO();
				// 商品ID
				String id = (String) doc.get("id");
				product.setId(id);
				Map<String, List<String>> map = new HashMap<String, List<String>>();
				if (null != highlighting) {
					map = highlighting.get(id);
				}

				// 商品名称
				if (null != map && null != map.get("jiucaiyun_name")) {
					product.setName(map.get("jiucaiyun_name").get(0));
				} else {
					product.setName((String) doc.get("jiucaiyun_name"));
				}
				product.setName1((String) doc.get("jiucaiyun_name"));
				// 供应商名称
				if (null != map && null != map.get("jiucaiyun_supplier_name")) {
					product.setSupplier(map.get("jiucaiyun_supplier_name").get(0));
				} else {
					product.setSupplier((String) doc.get("jiucaiyun_supplier_name"));
				}
				product.setSupplier1((String) doc.get("jiucaiyun_supplier_name"));
				// 供应商编码
				product.setSuppliernum((String) doc.get("jiucaiyun_suppliernum"));
				// 供应商id
				product.setSupplierid((String) doc.get("jiucaiyun_supplierid"));
				// wareId
				product.setWareid((String) doc.get("jiucaiyun_wareid"));

				//项目所属分类
				product.setFtnpjc((String) doc.get("jiucaiyun_ftnpjc"));
				//商品类型
				product.setFtnpconfiguration((String) doc.get("jiucaiyun_ftnpconfiguration"));
				// 商品sku
				product.setGoodsnum((String) doc.get("jiucaiyun_num"));
				product.setFreightprice((String) doc.get("jiucaiyun_freightprice"));
				// 商品品牌
				product.setBrand((String) doc.get("jiucaiyun_brand"));
				// 规格
				product.setModel((String) doc.get("jiucaiyun_model"));
				// 商品url
				product.setUrl((String) doc.get("jiucaiyun_picture"));
				// 商品imgid
				product.setImgid((String) doc.get("jiucaiyun_pictureid"));
				// 商品价格
				product.setPrice(String.valueOf(doc.get("jiucaiyun_price")));
				// 商品有效期
				product.setSuccessdate((String) doc.get("jiucaiyun_successdate"));
				// 商品销量
				product.setSalesvolume(String.valueOf(doc.get("jiucaiyun_salesvolume")));
				// 起购量
				product.setMinimumquantity((String) doc.get("jiucaiyun_minimum_quantity"));
				//价格类型是否实时价
				product.setPricetype((String) doc.get("jiucaiyun_pricetype"));
				if (null != request.getJiucaiyun_level() && !"".equals(request.getJiucaiyun_level())) {
					Integer goodsid = null;
					if (this.isNumeric(product.getId())) {
						goodsid = Integer.valueOf(product.getId());
						BigDecimal levelPrice = jiucaiyunSolrDao.getLevelPrice(goodsid, request.getJiucaiyun_level());
						if (null != levelPrice) {
							product.setPrice(levelPrice + "");
						}
					}
				}
				goodsList.add(product);
			}

			JiucaiyunSolrResponseDTO response = new JiucaiyunSolrResponseDTO();
			response.setGoodsList(goodsList);
			response.setBrands(brands);
			response.setCategory(category);
			response.setType(type);
			response.setModels(models);
			response.setTotalnum(numFound);
			if (null != request.getJiucaiyun_supplierid() && !"".equals(request.getJiucaiyun_supplierid().trim())) {
				String[] strs = request.getJiucaiyun_supplierid().split(",");
				List<JiucaiyunSolrSupplierDTO> suppliers = new ArrayList<>();
				for (String str : strs) {
					Long supplierid = Long.parseLong(str);
					JiucaiyunSolrSupplierDTO supplier = querySupplier(supplierid);
					suppliers.add(supplier);
				}
				response.setSuppliers(suppliers);
				response.setSupplier(suppliers.get(0));
			}
			return response;
		} catch (Exception e) {
			// logger.error(e.getMessage(),e);
			e.printStackTrace();
			return null;
		}
	}

	@Override
	public JiucaiyunSolrSupplierDTO querySupplier(Long id) throws JiucaiyunSolrException {
		try {
			JiucaiyunSolrSupplierDTO supplier = new JiucaiyunSolrSupplierDTO();
			JiucaiyunSupplier supplierquery = jiucaiyunSolrDao.getSupplier(id);
			supplier.setSupplier(supplierquery.getSupplier());
			supplier.setPhone(supplierquery.getPhone());
			supplier.setEmail(supplierquery.getEmail());
			return supplier;
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	@Override
	public Boolean productUpData(String id) throws JiucaiyunSolrException {
		try {
			String[] ids = id.split(",");
			Integer i = null;
			for (String str : ids) {
				i = Integer.valueOf(str);
				JiucaiyunSolr data = jiucaiyunSolrDao.getDataById(i);
				SolrInputDocument doc = new SolrInputDocument();
				doc.setField("jiucaiyun_pricetype",data.getPricetype());
				doc.setField("id", data.getId());
				doc.setField("jiucaiyun_name", data.getName());
				doc.setField("jiucaiyun_num", data.getGoodsnum());
				doc.setField("jiucaiyun_freightprice", data.getFreightprice());
				doc.setField("jiucaiyun_supplier_name", data.getSupplier());
				doc.setField("jiucaiyun_suppliernum", data.getSuppliernum());
				doc.setField("jiucaiyun_supplierid", data.getSupplierid());
				doc.setField("jiucaiyun_wareid", data.getWareid());
				doc.setField("jiucaiyun_description", data.getDescription());
				doc.setField("jiucaiyun_catalog", data.getCatalog());
				doc.setField("jiucaiyun_catalog_name", data.getCatalog() + "," + data.getCatalogname());
				doc.setField("jiucaiyun_price", data.getPrice());
				doc.setField("jiucaiyun_minimum_quantity", data.getMinimumquantity());
				doc.setField("jiucaiyun_ftnpjc", data.getFtnpjc());
				doc.setField("jiucaiyun_ftnpconfiguration", data.getFtnpconfiguration());
				String successdate = data.getSuccessdate();
				if (null == successdate || "".equals(successdate.trim())) {
					successdate = "长期有效";
				}
				doc.setField("jiucaiyun_successdate", successdate);
				doc.setField("jiucaiyun_salesvolume", data.getSalesVolume());
				doc.setField("jiucaiyun_brand", data.getBrand());
				doc.setField("jiucaiyun_brand_solr", data.getBrand());
				doc.setField("jiucaiyun_model", data.getModel());
				String url = data.getPricture();
				if ("京东".equals(data.getSupplier())) {
					doc.setField("jiucaiyun_type", "京东");
				} else if ("苏宁".equals(data.getSupplier())) {
					doc.setField("jiucaiyun_type", "苏宁");
				} else {
					doc.setField("jiucaiyun_type", "九彩云");
					url = preImage + url;
				}
				doc.setField("jiucaiyun_picture", url);
				doc.setField("jiucaiyun_pictureid", data.getImgid());
				
				String[] permissions = null;
				if (null != data.getSalesarea() && !"".equals(data.getSalesarea().trim())) {
					permissions = data.getSalesarea().split(",");
				} else {
					permissions = new String[] { "" };
				}
				doc.setField("jiucaiyun_permission", permissions);
				
				String[] licensorids = null;
				if (null != data.getLicensorid() && !"".equals(data.getLicensorid().trim())) {
					licensorids = data.getLicensorid().split(",");
				} else {
					licensorids = new String[] { "" };
				}
				doc.setField("jiucaiyun_licensorid", licensorids);
				
				String[] licensornames = null;
				if (null != data.getLicensorname() && !"".equals(data.getLicensorname().trim())) {
					licensornames = data.getLicensorname().split(",");
				} else {
					licensornames = new String[] { "" };
				}
				doc.setField("jiucaiyun_licensor_name", licensornames);

				
				doc.setField("jiucaiyun_last_modified", new Date());
				solrClient.add(doc);
				solrClient.commit();
			}
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
		return true;
	}

	@Override
	public Boolean productDownData(String id) throws JiucaiyunSolrException {
		try {
			String[] ids = id.split(",");
			for (String str : ids) {
				solrClient.deleteByQuery("id:" + str);
				solrClient.commit();
			}
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
		return true;
	}

	@Override
	public Boolean destoryData() throws JiucaiyunSolrException {
		try {
			solrClient.deleteByQuery("id:*");
			solrClient.commit();
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
		return true;
	}

	private boolean isNumeric(String str) {
		Pattern pattern = Pattern.compile("[0-9]*");
		Matcher isNum = pattern.matcher(str);
		if (!isNum.matches()) {
			return false;
		}
		return true;
	}

	@Override
	public Boolean productUpdateSalesNum(String data) throws JiucaiyunSolrException {
		try {
			if (null != data) {
				String[] strs = data.split(",");
				if(null!=strs&&strs.length>1) {
					for(String str:strs) {
						String id = strs[0];
						float salesnum =  Float.valueOf(strs[1]);
						
						SolrQuery params = new SolrQuery();
						params.add("q", "id:" + id);
						QueryResponse query = solrClient.query(params);
						SolrDocumentList results = query.getResults();
						if(null!=results&&results.size()>0) {
							SolrInputDocument inputdoc = new SolrInputDocument();
							SolrDocument doc = results.get(0);
							float oldnum = Float.valueOf(doc.get("jiucaiyun_salesvolume").toString());
							Float count = salesnum+oldnum;
							inputdoc.setField("id", (String) doc.get("id"));
							inputdoc.setField("jiucaiyun_name", doc.get("jiucaiyun_name"));
							inputdoc.setField("jiucaiyun_num", doc.get("jiucaiyun_num"));
							inputdoc.setField("jiucaiyun_supplier_name", doc.get("jiucaiyun_supplier_name"));
							inputdoc.setField("jiucaiyun_suppliernum", doc.get("jiucaiyun_suppliernum"));
							inputdoc.setField("jiucaiyun_supplierid", doc.get("jiucaiyun_supplierid"));
							inputdoc.setField("jiucaiyun_wareid", doc.get("jiucaiyun_wareid"));
							inputdoc.setField("jiucaiyun_description", doc.get("jiucaiyun_description"));
							inputdoc.setField("jiucaiyun_catalog", doc.get("jiucaiyun_catalog"));
							inputdoc.setField("jiucaiyun_catalog_name", doc.get("jiucaiyun_catalog_name"));
							inputdoc.setField("jiucaiyun_price", doc.get("jiucaiyun_price"));
							inputdoc.setField("jiucaiyun_minimum_quantity", doc.get("jiucaiyun_minimum_quantity"));
							inputdoc.setField("jiucaiyun_successdate", doc.get("jiucaiyun_successdate"));
							inputdoc.setField("jiucaiyun_salesvolume", count);
							inputdoc.setField("jiucaiyun_brand", doc.get("jiucaiyun_brand"));
							doc.setField("jiucaiyun_brand_solr", doc.get("jiucaiyun_brand_solr"));
							inputdoc.setField("jiucaiyun_type", doc.get("jiucaiyun_type"));
							inputdoc.setField("jiucaiyun_model", doc.get("jiucaiyun_model"));
							inputdoc.setField("jiucaiyun_picture", doc.get("jiucaiyun_picture"));
							inputdoc.setField("jiucaiyun_pictureid", doc.get("jiucaiyun_pictureid"));
							inputdoc.setField("jiucaiyun_permission", doc.get("jiucaiyun_permission"));
							inputdoc.setField("jiucaiyun_last_modified", doc.get("jiucaiyun_last_modified"));
							inputdoc.setField("jiucaiyun_ftnpjc",doc.get("jiucaiyun_ftnpjc"));
							inputdoc.setField("jiucaiyun_ftnpconfiguration", doc.get("jiucaiyun_ftnpconfiguration"));
							inputdoc.setField("jiucaiyun_pricetype",doc.get("jiucaiyun_pricetype"));
							solrClient.add(inputdoc);
							solrClient.commit();
							return true;
						}
					}
				}
			}
			return false;
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
	}

}
